<?php
/**
 * Quando o periodo de apuração for ultrapassado
 */
namespace Faturamento\Logic\ApuracaoFaturamento\Exception;

class PeriodoApuracao extends \Faturamento\Logic\Exception
{

    private $messageName;

    /**
     * Construtor.
     *
     * Recebe o nome da mensagem cadastrada no setforms.
     *
     * @param string $messageName
     * @param string $message
     * @param int $code
     * @param \Exception|null $previous
     */
    public function __construct($messageName, $code = 0, \Exception $previous = null)
    {
        parent::__construct($messageName, $code, $previous);
        $this->messageName = $messageName;
    }


    /**
     * Retorna o nome da mensagem cadastrada no Setforms para esta excecao.
     *
     * @return string
     */
    public function getMessageName()
    {
        return $this->messageName;
    }


    /**
     * Confimar apuração fora do periodo mensal
     * @static
     * @throws PeriodoApuracao
     */
    public static function confirmaApuracaoForaPeriodoMensal()
    {
        throw new self (tk_get_message_by_name("fai00800_informa_period_fat_mensal"));
    }


    /**
     * Confimar apuração fora do periodo quinzenal
     * @static
     * @throws PeriodoApuracao
     */
    public static function confirmaApuracaoForaPeriodoQuinzenal()
    {
        throw new self (tk_get_message_by_name("fai00800_informa_period_fat_quinzenal"));
    }


    /**
     * Confimar apuração fora do periodo decendial
     * @static
     * @throws PeriodoApuracao
     */
    public static function confirmaApuracaoForaPeriodoDecendial()
    {
        throw new self (tk_get_message_by_name("fai00800_informa_period_fat_decendial"));
    }


    /**
     * Confimar apuração fora do periodo semanal
     * @static
     * @throws PeriodoApuracao
     */
    public static function confirmaApuracaoForaPeriodoSemanal()
    {
        throw new self (tk_get_message_by_name("fai00800_informa_period_fat_semanal"));
    }


}